    	import pathlib
    	from os.path import dirname, join, normpath
    	this_directory = pathlib.Path (__file__).parent.resolve ()
    	this_module = str (normpath (join (this_directory, "..")))

    	import homeostasis
    	scan = homeostasis.start (
    		glob_string = this_module + "/**/status_*.py",

    		#
    		#	This runs all the checks in a thread pool,
    		#	so maybe at the same time, more or less.
    		#
    		simultaneous = True,

    		#
    		#	If the process requires locally installed
    		#	modules in custom places.
    		#
    		module_paths = [
    			normpath (join (this_module, "modules")),
    			normpath (join (this_module, "modules_pip"))
    		],

    		#
    		#	This removes the substring provided
    		#	from the output.
    		#
    		#	For example:
    		#		if
    		#			"this_module" = /modules/this_module/1"
    		#			and the status file path = /modules/this_module/1/_status/status_1.py
    		#
    		#		then,
    		#			the path shown in the output is "_status/status_1.py"
    		#
    		relative_path = this_module
    	)